@@ -14,7 +14,7 @@ Server users: data bag search, and node search.
 .. _Chef: http://wiki.opscode.com/display/chef/Home
 
 """
-__version__ = "1.5.2"
+__version__ = "1.6.0"
 __author__ = "Miquel Torres <tobami@gmail.com>"
 
 __cooking__ = False
@@ -25,11 +25,11 @@ loglevel = "info"
 noninteractive = False
 verbose = False
 enable_logs = True
-LOGFILE = '/var/log/chef/solo.log'
+LOGFILE = "/var/log/chef/solo.log"
 whyrun = False
 concurrency = False
 
-node_work_path = '/tmp/chef-solo'
+node_work_path = "/tmp/chef-solo"
 cookbook_paths = ['site-cookbooks', 'cookbooks']
 
-CONFIGFILE = 'config.cfg'
+CONFIGFILE = "littlechef.cfg"
